def search_url(submit):
    url = "https://www.104.com.tw/jobs/search/?jobsource=2018indexpoc&ro=0"
    ori_url = "https://www.104.com.tw/jobs/search/?jobsource=2018indexpoc&ro=0"
    j = jobtype(submit)
    a = area(submit)
    u = update_date(submit)
    s = salary_type(submit)
    s2 = salary_conditions(submit)
    e = experience(submit)
    url = f"{ori_url}&{j}&{a}&{u}&{s}&{s2}&{e}"
    while "&&" in url:
        url = url.replace("&&", "&")
    return url

jdict = {
    "經營／人資類" : "2001000000" ,
    "行政／總務／法務類" : "2002000000" ,
    "財會／金融專業類" : "2003000000" ,
    "行銷／企劃／專案管理類" : "2004000000" ,
    "客服／門市／業務／貿易類" : "2005000000" ,
    "餐飲／旅遊 ／美容美髮類" : "2006000000" ,
    "資訊軟體系統類" : "2007000000" ,
    "操作／技術／維修類" : "2010000000" ,
    "資材／物流／運輸類" : "2011000000" ,
    "營建／製圖類" : "2012000000" ,
    "傳播藝術／設計類" : "2013000000" ,
    "文字／傳媒工作類" : "2014000000" ,
    "醫療／保健服務類" : "2015000000" ,
    "學術／教育／輔導類" : "2016000000" ,
    "研發相關類" : "2008000000" ,
    "生產製造／品管／環衛類" : "2009000000" ,
    "軍警消／保全類" : "2017000000" ,
    "其他職類" : "2018000000" 
}

def salary_conditions(submit):
    salary = ""
    s1 = submit["薪資待遇"]
    s2 = submit["薪資下限"]
    s3 = submit["薪資上限"]
    if s1 == "default": #不限就沒東西
        return ""
    elif s1 == "any":
        salary = "sr=99"
    elif s1 == "30000":
        salary = "scmin=30000&scstrict=1 "
    elif s1 == "40000":
        salary = "scmin=40000&scstrict=1 "
    elif s1 == "50000":
        salary = "scmin=50000&scstrict=1 "
    elif s1 == "custom":
        salary = f"scmin={s2}&scstrict=1"
        if s3:
            salary = salary + f"&scmax={s3}"
    else:
        print("薪資範圍出錯", s1,s2,s3)
        return ""
            
    stype = salary_type(submit)
    if not stype: #新增stype
        salary = salary + "&sctp=M"
    
    return salary

#職缺類型  目前不會有list input，只是之後擴充可用
def jobtype(submit):
    jobtype = ""
    if isinstance(submit["職務類別"], str):
        if submit["職務類別"] == "不限": #不限就不需要了
            return ""
        jobtype = jdict[submit["職務類別"]]
    elif isinstance(submit["職務類別"], list):
        for n in submit["職務類別"]:
            if jobtype:#如果前面有資料就加逗號
                jobtype += ","
            jobtype += jdict[n] 
    jobtype = "jobcat=" + jobtype
    return jobtype

#地區條件，基本上進來不管幾個都會是list
def area(submit):
    area = ""
    s = submit["地區條件"]
    if not s: #如果地區條件沒內容
        return ""
    if "all" in s: #不限的話就直接全選
        return ""
    for n in s:
        if area:
            area += ","
        area += n
    area = "area=" + area
    return area

#更新日期
def update_date(submit):
    date = ""
    u = submit["更新日期"]
    if u == "不限":
        return ""
    elif u == "本日最新":
        date = "1"
    elif u == "三日內":
        date = "3"
    elif u == "一週內":
        date = "7"
    elif u == "二週內":
        date = "14"
    elif u == "一個月內":
        date = "30"
    else:
        print("日期出錯", u)
    
    date = "isnew=" + date
    return date

#薪資型態
def salary_type(submit):
    s = submit["薪資類型"]
    stype = "" 
    if s == "月薪":
        stype = "M"
    elif s == "年薪":
        stype = "Y"
    elif s == "日薪":
        stype = "D"
    elif s == "時薪":
        stype = "H" 
    elif s == "不限":#不限直接retunr
        return ""
    else:
        print("薪資型態出錯", s)
        return ""
    
    stype = "sctp=" + stype
    return stype
    
#經歷要求
def experience(submit):
    e = submit["經歷要求"]
    exp = ""
    if e == "不限":
        return ""
    elif e == "1年以下":
        exp = "1"
    elif e == "1-3年":
        exp = "3"
    elif e == "3-5年":
        exp = "5"
    elif e == "5-10年":
        exp = "10"
    elif e == "10年以上":
        exp = "99"
    else:
        print("經歷出錯", e)
        return ""
    exp = "jobexp=" + exp
    return exp

if __name__ == "__main__":
    dict1 = dict1 = {'職務類別': '操作／技術／維修類', '地區條件': ['6001002000', '6001011000'], '更新日期': '一週內', '薪資類型': '年薪', '薪資待遇': 'custom', '薪資下限': '35000', '薪資上限': '', '經歷要求': '3-5年'}
    print(search_url(dict1))

    


import os
import requests
import time
import pandas as pd
import re
from bs4 import BeautifulSoup
from lxml import html
from collections import Counter
import matplotlib.pyplot as plt
import seaborn as sns
#中文
plt.rcParams['font.sans-serif'] = ['Microsoft JhengHei'] 
plt.rcParams['axes.unicode_minus'] = False


class Jobs:
    
    def __init__ (self, keyword):
        self.keyword = keyword
        self.job_links = []
        self.jobs = []
        self.data = []
        
    def xpath_match(self, col_name, index):
        match = {"職務類別" : f"/html/body/div[2]/div/div[2]/div/div[1]/div[1]/div[2]/div[{index}]/div[2]/div/div//*/div/div/u",
             "工作待遇" : f"/html/body/div[2]/div/div[2]/div/div[1]/div[1]/div[2]/div[{index}]/div[2]/div/p[1]",
             "工作性質" : f"/html/body/div[2]/div/div[2]/div/div[1]/div[1]/div[2]/div[{index}]/div[2]/div",
             "上班地點" : f"/html/body/div[2]/div/div[2]/div/div[1]/div[1]/div[2]/div[{index}]/div[2]/div/div/span[1]",
             "遠端工作" : f"/html/body/div[2]/div/div[2]/div/div[1]/div[1]/div[2]/div[{index}]/div[2]/div", 
             "上班時段" : f"/html/body/div[2]/div/div[2]/div/div[1]/div[1]/div[2]/div[{index}]/div[2]/div",
             "休假制度" : f"/html/body/div[2]/div/div[2]/div/div[1]/div[1]/div[2]/div[{index}]/div[2]/div",
             "可上班日" : f"/html/body/div[2]/div/div[2]/div/div[1]/div[1]/div[2]/div[{index}]/div[2]/div",
             "需求人數" : f"/html/body/div[2]/div/div[2]/div/div[1]/div[1]/div[2]/div[{index}]/div[2]/div",
             "管理責任" : f"/html/body/div[2]/div/div[2]/div/div[1]/div[1]/div[2]/div[{index}]/div[2]/div",
             "出差外派" : f"/html/body/div[2]/div/div[2]/div/div[1]/div[1]/div[2]/div[{index}]/div[2]/div",
             "法定項目" : f"/html/body/div[2]/div/div[2]/div/div[1]/div[4]/div[{index + 1}]/div//*/a",
             "其他福利" : f"/html/body/div[2]/div/div[2]/div/div[1]/div[4]/div[{index + 1}]/div//*/a",
             "工作經歷" : f"/html/body/div[2]/div/div[2]/div/div[1]/div[2]/div[2]/div[{index}]/div[2]/div",
             "學歷要求" : f"/html/body/div[2]/div/div[2]/div/div[1]/div[2]/div[2]/div[{index}]/div[2]/div",
             "科系要求" : f"/html/body/div[2]/div/div[2]/div/div[1]/div[2]/div[2]/div[{index}]/div[2]/div",    
             "擅長工具" : f"/html/body/div[2]/div/div[2]/div/div[1]/div[2]/div[2]/div[{index}]/div[2]/div//*/a/u",   
             "工作技能" : f"/html/body/div[2]/div/div[2]/div/div[1]/div[2]/div[2]/div[{index}]/div[2]/div//*/a/u",
             "具備證照" : f"/html/body/div[2]/div/div[2]/div/div[1]/div[2]/div[2]/div[{index}]/div[2]/div//*/p/a/u",
             "其他條件" : f"/html/body/div[2]/div/div[2]/div/div[1]/div[2]/div[3]/div/div[2]/div/div/p",
             "具備駕照" : f"/html/body/div[2]/div/div[2]/div/div[1]/div[2]/div[2]/div[{index}]/div[2]/div",
            }
        return match.get(col_name)

    def search_links(self, max_pages = 3, ori_url = None):
        page = 1
        data = []
        if ori_url == None:
            ori_url = f'https://www.104.com.tw/jobs/search/?ro=0&kwop=7&keyword={self.keyword}&expansionType=area%2Cspec%2Ccom%2Cjob%2Cwf%2Cwktm&order=15&asc=0&mode=s&jobsource=2018indexpoc&langFlag=0&langStatus=0&recommendJob=1&hotJob=1'
        print(f"開始搜尋關鍵字: {self.keyword}")
        while True:
            url = ori_url + f"&page={page}"
            res = requests.get(url, timeout=10)
            soup = BeautifulSoup(res.text, features="lxml")
            jobs = soup.find_all('article', class_='b-block--top-bord job-list-item b-clearfix js-job-item')
            if not jobs:#找不到內容就中斷
                break
            print("現在正在讀取第" + str(page) + "頁")
            for job in jobs:
                title = job['data-job-name'].strip()
                company = job('li')[1].text.strip()
                URL = 'https:' + job.find("a", class_='js-job-link')['href']
                dict1 = {"公司名稱": company, "職缺名稱": title, "職缺連結": URL}
                data.append(dict1)
            if page == max_pages:
                break
            page += 1
        if data:
            self.job_links = pd.DataFrame(columns = data[0].keys(), data = data)
            print("-"*20)
            print("已完成搜尋，請使用find_jobs爬取工作資料")
            print("-"*20)
        else:
            print("查詢失敗")
            self.job_links = pd.DataFrame()
        return self.job_links
        
    def save_jobs_link(self):
        if not self.job_links:
            print("無資料可儲存")
            return
        path = self.keyword + r"-職缺連結.xlsx" #定義檔案路徑 #當檔案名稱有中文要加r
        df.to_excel(path, index = False)
        print("檔案儲存", path)
    
    def load_jobs_link(self, path = None):
        if not path:
            path = self.keyword + "-職缺連結.xlsx"
        if path not in os.listdir:
            print(f"找不到{path} 之資料，請先使用find_jobs & save_to_excel產生職位列表檔案")
            return
        self.job_links = pd.read_excel(path)
        return self.job_links
    
    def list2string(self, list_): #修改list資料變成string，因為在excel中比較好處理
        if type(list_) == str:
            return list_
        elif not list_:#空list
            return ""
        elif type(list_) == list:
            try:
                output = ",".join(list_)
            except:
                output = ""
            return output
        else:
            #print("型態錯誤，非list&str, 回傳空白")
            return ""
    
    #從個別職缺的網頁中取得資料
    def creep_job(self, url):
        res = requests.get(url, timeout=10)
        tree = html.fromstring(res.text)
        data_dict = {}
        title = tree.xpath("/html/body/div[2]/div/div[1]/div[2]/div/div/div[1]/h1")
        company = tree.xpath("/html/body/div[2]/div/div[1]/div[2]/div/div/div[1]/div/a[1]")
        work = tree.xpath("/html/body/div[2]/div/div[2]/div/div[1]/div[1]/div[2]/div[1]/p")
       
        data_dict["職務名稱"] = title[0].text.strip()
        #data_dict["公司名稱"] = company[0].text #上面好像有了
        for index in range(2,15):
            p1 = tree.xpath(f"/html/body/div[2]/div/div[2]/div/div[1]/div[1]/div[2]/div[{index}]/div[1]/h3")
            if p1:
                col_name = p1[0].text.strip()     
                xpath = self.xpath_match(col_name, index)
                data_dict[col_name] = []
            else:
                continue
            if not xpath:
                print(i, "no xpath")
                continue
            p2 = tree.xpath(xpath)
            for n in p2:
                data_dict[col_name].append(n.text.strip())
        
        #條件要求
        language = tree.xpath("/html/body/div[2]/div/div[2]/div/div[1]/div[2]/div[2]/div[4]/div[2]/div/p")
        if not language[0].text: #代表並非"不拘"
            language_set = []
            language_set_e = tree.xpath("/html/body/div[2]/div/div[2]/div/div[1]/div[2]/div[2]/div[4]/div[2]/div//*/a/u")
            for n in language_set_e:
                language_set.append(n.text)
        else:
            language_set = "不拘"
        data_dict["語文條件"] = self.list2string(language_set)

        for index in range(10):
            p1 = tree.xpath(f"/html/body/div[2]/div/div[2]/div/div[1]/div[2]/div[2]/div[{index}]/div[1]/h3")
            if p1:
                col_name = p1[0].text.strip()
                if col_name not in data_dict.keys(): #避免蓋掉已經存在的部分
                    data_dict[col_name] = []
                xpath = self.xpath_match(col_name, index)
            else:
                continue
            if not xpath:
                continue
            p2 = tree.xpath(xpath)
            for n in p2:
                data_dict[col_name].append(n.text.strip())
        
        other_requirements = tree.xpath("/html/body/div[2]/div/div[2]/div/div[1]/div[2]/div[3]/div/div[2]/div/div/p")


        #福利相關
        for index in range(1,8):
            p1 = tree.xpath(f"/html/body/div[2]/div/div[2]/div/div[1]/div[4]/div[{index}]/div/h3")
            if p1:
                col_name = p1[0].text.strip()
                data_dict[col_name] = []
                xpath = self.xpath_match(col_name, index)
            else:
                continue
            if not xpath:
                print(f"{col_name}: no xpath")
                continue
            p2 = tree.xpath(xpath)
            for n in p2:
                data_dict[col_name].append(n.text.strip())
        
        recruit_incentives = tree.xpath("/html/body/div[2]/div/div[2]/div/div[1]/div[4]/div[6]/div/p")#div6
        if recruit_incentives:
            data_dict["招募福利"] = recruit_incentives[0].text
            
        #薪資待遇拆解
        salary_dict = self.parse_salary(data_dict["工作待遇"][0])
        data_dict = {**data_dict, **salary_dict}

        return data_dict

    def find_jobs(self, max_jobs = -1):
        #爬取所有頁面的資料
        if max_jobs == -1:
            max_jobs = self.job_links.shape[0]
        data = []
        for i in range(self.job_links.shape[0]):
            company = self.job_links["公司名稱"].iloc[i]
            job = self.job_links["職缺名稱"].iloc[i]
            url = self.job_links["職缺連結"].iloc[i]
            dict_data_jobs = {
                "公司名稱" : company,
                "職缺名稱" : job,
                "職缺連結" : url
            }
            try:
                job_data = self.creep_job(url)
                job_data = {**dict_data_jobs, **job_data}
                data.append(job_data)
                print(f"正在爬取第{i+1}/{min(self.job_links.shape[0], max_jobs)}個工作")
            except KeyboardInterrupt:
                break
            except:
                continue
            if i >= max_jobs-1:
                break        
        fields =['公司名稱', '職缺名稱', '職缺連結', '職務名稱', '職務類別', '工作待遇',
                 '薪資型態', '薪資下限', '薪資上限',
                 '工作性質', '上班地點', '遠端工作', '管理責任', '出差外派', '上班時段',
                 '休假制度', '可上班日', '需求人數', '語文條件', '工作經歷', '學歷要求',
                 '科系要求', '擅長工具', '工作技能', '具備駕照', '具備證照', '法定項目',
                 '其他福利', '招募福利']
        df = pd.DataFrame(columns = fields, data = data)
        self.data = df.copy()
        #針對統計用欄位做處理
        self.data["語文條件"] = self.data["語文條件"].apply(lambda x : x.split(","))#拆分語言
        self.data["科系要求"] = self.data["科系要求"].apply(lambda x: x[0].split("、") if type(x) == list else x)
        self.data["具備駕照"] = self.data["具備駕照"].apply(lambda x: x[0].split("、") if type(x) == list else x)
        self.data["學歷要求"] = self.data["學歷要求"].apply(lambda x: x[0].split("、") if type(x) == list else x)
        self.jobs = df
        print("資料已爬取完畢，請用self.jobs檢視資料或以save_jobs儲存檔案")
        return self.jobs
    
    def save_jobs(self):
        if self.jobs is None:
            print("尚未爬取職位資料，請先find jobs")
            return
        for column in self.jobs.columns:
            self.jobs[column] = self.jobs[column].apply(self.list2string)
        path = self.keyword + r"-職位資料爬蟲.xlsx"
        self.jobs.to_excel(path, index = False)
        print(f"{path}資料已儲存")
        
    def show(self, column, top = 10):
        total = self.data.shape[0]
        if column == "all":#畫出全部的
            for column_ in self.data.columns:
                static = Counter(self.flatten(self.data[column_].dropna().tolist()))
                common = static.most_common()
                if not common:
                    print(f"{column_}: 資料不足無法繪圖")
                    continue
                self.draw(column_, data = common, total = total, top = top )
        else:
            static = Counter(self.flatten(self.data[column].dropna().tolist()))
            common = static.most_common()
            if not common:
                print(print(f"{column}: 資料不足無法繪圖"))
            self.draw(column, data = common, total = total, top = top )
    
    def flatten(self, list_):
        new_list = []
        for n in list_:
            if isinstance(n, list):
                new_list.extend(self.flatten(n))
            else:
                new_list.append(n)
        return new_list
    
    def draw(self, column, data, total, top = 10):
        # 使用中文字體
        plt.rcParams['font.sans-serif'] = ['Microsoft JhengHei'] 
        plt.rcParams['axes.unicode_minus'] = False

        # 將技能和頻率分開，並計算百分比
        skills, frequencies = zip(*data[:top])
        percentages = [f/total*100 for f in frequencies]

        # 繪製水平條形圖
        plt.figure(figsize=(10,10))  # 設定圖形大小
        bars = plt.barh(skills, frequencies, color='skyblue')
        plt.xlabel('次數')  # x軸標籤
        plt.title(column)  # 圖形標題

        # 在條形旁邊添加百分比數據
        for bar, percentage in zip(bars, percentages):
            plt.text(bar.get_width() + 0.2, bar.get_y() + bar.get_height()/2, 
                     '{0:.1f}%'.format(percentage), va='center')

        # 顯示圖形
        plt.gca().invert_yaxis()  # 倒轉y軸，讓最高的頻率在頂部
        plt.show()
        return plt
    
    def parse_salary(self, s):
        pattern_1 = r"(時薪|面議|月薪|年薪|論件計酬|日薪)([\d,]+)~([\d,]+)元"
        pattern_2 = r"(時薪|面議|月薪|年薪|論件計酬|日薪)([\d,]+)元以上"
        pattern_3 = r"(時薪|面議|月薪|年薪|論件計酬|日薪)([\d,]+)元"
        pattern_4 = r"待遇面議"

        if re.match(pattern_1, s):
            salary_type, min_salary, max_salary = re.match(pattern_1, s).groups()
            return {"薪資型態": salary_type, "薪資下限": min_salary, "薪資上限": max_salary}
        elif re.match(pattern_2, s):
            salary_type, min_salary = re.match(pattern_2, s).groups()
            return {"薪資型態": salary_type, "薪資下限": min_salary, "薪資上限": "無上限"}
        elif re.match(pattern_3, s):
            salary_type, salary = re.match(pattern_3, s).groups()
            return {"薪資型態": salary_type, "薪資下限": salary, "薪資上限": salary}
        elif re.match(pattern_4, s):
            return {"薪資型態": "待遇面議", "薪資下限": "面議", "薪資上限": "面議"}
        else:
            return {"薪資型態": "未知", "薪資下限": "未知", "薪資上限": "未知"}
    
    def draw_box(self, show = True):
        plt.figure() #清空圖形，不然連續呼叫時會出錯
        df = self.jobs.copy()
        # Filter the dataframe
        df = df[df['薪資型態'] == '月薪']
        df = df[(df['薪資下限'] != '面議') & (df['薪資上限'] != '面議')]
        # Replace '無上限' with '薪資下限'
        df.loc[df['薪資上限'] == '無上限', '薪資上限'] = df.loc[df['薪資上限'] == '無上限', '薪資下限']
        # Convert to numeric values
        df['薪資下限'] = df['薪資下限'].str.replace(',', '').astype(float)
        df['薪資上限'] = df['薪資上限'].str.replace(',', '').astype(float)
        # Plot boxplot
        df[['薪資下限', '薪資上限']].plot(kind='box')
        plt.title(self.keyword + '月薪下限和上限的箱型圖')
        plt.ylabel('薪資')
        plt.savefig("./static/temp/salary_boxplot.png", dpi=150, bbox_inches='tight')
        if show:
            plt.show()
        return plt
    
    def draw_density(self, show = True):
        plt.figure() #清空圖形，不然連續呼叫時會出錯
        df = self.jobs.copy()
        # Filter the dataframe
        df = df[df['薪資型態'] == '月薪']
        df = df[(df['薪資下限'] != '面議') & (df['薪資上限'] != '面議')]

        # Replace '無上限' with '薪資下限'
        df.loc[df['薪資上限'] == '無上限', '薪資上限'] = df.loc[df['薪資上限'] == '無上限', '薪資下限']

        # Convert to numeric values
        df['薪資下限'] = df['薪資下限'].str.replace(',', '').astype(float)
        df['薪資上限'] = df['薪資上限'].str.replace(',', '').astype(float)

        # Plot the kernel density estimation for salary lower and upper limit
        df['薪資下限'].plot(kind='kde', label='薪資下限')
        df['薪資上限'].plot(kind='kde', label='薪資上限')

        plt.title(self.keyword + '月薪下限和上限的密度分佈')
        plt.xlabel('薪資')
        plt.ylabel('密度')
        plt.legend()
        plt.savefig("./static/temp/salary_density.png", bbox_inches='tight')
        if show:
            plt.show()
        return plt

if __name__ == "__main__":
    keyword = "分析師"
    jobs = Jobs(keyword)
    jobs.search_links(max_pages = 1)#一頁是20個職缺
    jobs.find_jobs()
    jobs.save_jobs()
    jobs.draw_box()
    jobs.draw_density()
    #jobs.show("all") #一次秀出全部
    jobs.show("職務類別")


from flask import Flask, render_template, request, redirect, url_for
import webbrowser
from threading import Timer
from .url import search_url
import pandas as pd
from .FindJobs import Jobs

app = Flask(__name__)



def findjobs(conditions):
    text = f"findjobs function has been executed with:<br>" 
    for k,v in conditions.items():
        text += f"{k}: {v}<br>"
    return text

@app.route('/', methods=['GET', 'POST'])
def home():
    message = ''
    global JobKeyword
    JobKeyword = ''
    global jobNumber
    jobNumber = ''
    global job_type
    job_type = ''
    global area_condition
    area_condition = ''
    global update_date
    update_date = ''
    global attendance_system
    attendance_system = ''
    global salarytype
    salarytype = ''
    global salary_condition
    salary_condition = ''
    global custom_salary_min
    custom_salary_min = ''
    global custom_salary_max
    custom_salary_max = ''
    global experience
    experience = ''
    image_filename = None
    image_filename2 = None
    message = ""
    df = None
    table = None
    if request.method == 'POST':
        if 'clear' in request.form:
            # 如果按下了 "清除" 按鈕，將所有的模板變數設為空
            return render_template('index.html', message="", 
                           table = "",
                           current_JobKeyword = "",
                           current_JobNumber = "",
                           current_job_type="", 
                           current_area_condition = "",
                           current_update_date = "",
                           current_attendance_system = "",
                           current_salarytype = "",
                           current_salary_condition = "",
                           current_custom_salary_min = "",
                           current_custom_salary_max = "",
                           current_experience = "")
        JobKeyword = request.form.get('JobKeyword')
        jobNumber = request.form.get('JobNumber')
        job_type = request.form.get('job_type')
        area_condition = request.form.getlist('area_condition')
        update_date = request.form.get('update_date')
        attendance_system = request.form.get('attendance_system')
        salarytype = request.form.get('salarytype')
        salary_condition = request.form.get('salary_condition')
        custom_salary_min = request.form.get('custom_salary_min')
        custom_salary_max = request.form.get('custom_salary_max')
        experience = request.form.get('experience')
        conditions = {}
        conditions["關鍵字"] = JobKeyword
        conditions["搜尋數量"] = jobNumber
        conditions["職務類別"] = job_type
        conditions["地區條件"] = area_condition
        conditions["更新日期"] = update_date
        conditions["薪資類型"] = salarytype
        conditions["薪資待遇"] = salary_condition
        conditions["薪資下限"] = custom_salary_min
        conditions["薪資上限"] = custom_salary_max
        conditions["經歷要求"] = experience
        print(conditions)
        url = search_url(conditions)
        print(url)
        message = findjobs(conditions)
        
        job = Jobs(JobKeyword)
        job.search_links(max_pages=int(int(jobNumber)/20)+1, ori_url = url)
        job.find_jobs(max_jobs = int(jobNumber))
        job.draw_box(show = False)
        job.draw_density(show = False)
        job.save_jobs()
        df = job.jobs.head(10)
        table = df.to_html(classes='data', header="true", index="false")
        image_filename = 'temp/salary_boxplot.png'
        image_filename2 = 'temp/salary_density.png'
    
    return render_template('index.html', message=message, 
                           table = table,
                           current_JobKeyword = JobKeyword,
                           current_JobNumber = jobNumber,
                           current_job_type=job_type, 
                           current_area_condition = area_condition,
                           current_update_date = update_date,
                           current_attendance_system = attendance_system,
                           current_salarytype = salarytype,
                           current_salary_condition = salary_condition,
                           current_custom_salary_min = custom_salary_min,
                           current_custom_salary_max = custom_salary_max,
                           current_experience = experience,
                           image_filename=image_filename,
                           image_filename2 = image_filename2)

@app.route('/execute')
def execute_findjobs():
    result = findjobs()
    if result is None:
        result = "No result returned from findjobs"
    return render_template('index.html', message=result)

def open_browser():
    webbrowser.open_new('http://127.0.0.1:5000/')

@app.route('/some_route')
def some_route():
    # Generate or select the image
    image_filename = 'temp/salary_boxplot.png'
    
    # Render the template
    return render_template('index.html', image_filename=image_filename)

if __name__ == '__main__':
    Timer(1, open_browser).start()
    app.run(debug=True, use_reloader=False)


import setuptools
from setuptools import setup, find_packages

with open('requirements.txt') as f:
    requirements = f.read().splitlines()
    
setup(
    name='FindJobsTW',    
    version='1.0.3',      
    packages=find_packages(),    
    install_requires=requirements,
    package_data={
        'findJobs': ['templates/*', 'static/*']
    },  
    author="Danny Fin",
    author_email="dannyfinselect@outlook.com",
    description="A Python package to find jobs on 104.com.tw based on specific keywords.",
    long_description=open('README.md', 'r', encoding='utf-8').read(),# 若Discription.md中有中文 須加上 encoding="utf-8"
    long_description_content_type="text/markdown",
    url="https://github.com/DannyFin/FindJobsTW",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)